==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_service_get_quartiles_response_200_quartiles_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.pool_service_get_quartiles_response_200_quartiles_item_age import (
    PoolService_GetQuartilesResponse_200QuartilesItemAge,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_credit_score import (
    PoolService_GetQuartilesResponse_200QuartilesItemCreditScore,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_odti import (
    PoolService_GetQuartilesResponse_200QuartilesItemODTI,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_ols import (
    PoolService_GetQuartilesResponse_200QuartilesItemOLS,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_oltv import (
    PoolService_GetQuartilesResponse_200QuartilesItemOLTV,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetQuartilesResponse_200QuartilesItem")


@attr.s(auto_attribs=True)
class PoolService_GetQuartilesResponse_200QuartilesItem:
    """ Quartiles data on Loans characteristics: credit scores, OLTV, OLS, age, ODTI. """

    cusip: Union[Unset, str] = UNSET
    odti: Union[PoolService_GetQuartilesResponse_200QuartilesItemODTI, Unset] = UNSET
    ols: Union[PoolService_GetQuartilesResponse_200QuartilesItemOLS, Unset] = UNSET
    oltv: Union[PoolService_GetQuartilesResponse_200QuartilesItemOLTV, Unset] = UNSET
    age: Union[PoolService_GetQuartilesResponse_200QuartilesItemAge, Unset] = UNSET
    credit_score: Union[
        PoolService_GetQuartilesResponse_200QuartilesItemCreditScore, Unset
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cusip = self.cusip
        odti: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.odti, Unset):
            odti = self.odti.to_dict()

        ols: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ols, Unset):
            ols = self.ols.to_dict()

        oltv: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.oltv, Unset):
            oltv = self.oltv.to_dict()

        age: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.age, Unset):
            age = self.age.to_dict()

        credit_score: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.credit_score, Unset):
            credit_score = self.credit_score.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cusip is not UNSET:
            field_dict["CUSIP"] = cusip
        if odti is not UNSET:
            field_dict["ODTI"] = odti
        if ols is not UNSET:
            field_dict["OLS"] = ols
        if oltv is not UNSET:
            field_dict["OLTV"] = oltv
        if age is not UNSET:
            field_dict["age"] = age
        if credit_score is not UNSET:
            field_dict["creditScore"] = credit_score

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cusip = d.pop("CUSIP", UNSET)

        odti: Union[
            PoolService_GetQuartilesResponse_200QuartilesItemODTI, Unset
        ] = UNSET
        _odti = d.pop("ODTI", UNSET)
        if not isinstance(_odti, Unset):
            odti = PoolService_GetQuartilesResponse_200QuartilesItemODTI.from_dict(
                cast(Dict[str, Any], _odti)
            )

        ols: Union[PoolService_GetQuartilesResponse_200QuartilesItemOLS, Unset] = UNSET
        _ols = d.pop("OLS", UNSET)
        if not isinstance(_ols, Unset):
            ols = PoolService_GetQuartilesResponse_200QuartilesItemOLS.from_dict(
                cast(Dict[str, Any], _ols)
            )

        oltv: Union[
            PoolService_GetQuartilesResponse_200QuartilesItemOLTV, Unset
        ] = UNSET
        _oltv = d.pop("OLTV", UNSET)
        if not isinstance(_oltv, Unset):
            oltv = PoolService_GetQuartilesResponse_200QuartilesItemOLTV.from_dict(
                cast(Dict[str, Any], _oltv)
            )

        age: Union[PoolService_GetQuartilesResponse_200QuartilesItemAge, Unset] = UNSET
        _age = d.pop("age", UNSET)
        if not isinstance(_age, Unset):
            age = PoolService_GetQuartilesResponse_200QuartilesItemAge.from_dict(
                cast(Dict[str, Any], _age)
            )

        credit_score: Union[
            PoolService_GetQuartilesResponse_200QuartilesItemCreditScore, Unset
        ] = UNSET
        _credit_score = d.pop("creditScore", UNSET)
        if not isinstance(_credit_score, Unset):
            credit_score = (
                PoolService_GetQuartilesResponse_200QuartilesItemCreditScore.from_dict(
                    cast(Dict[str, Any], _credit_score)
                )
            )

        pool_service_get_quartiles_response_200_quartiles_item = cls(
            cusip=cusip,
            odti=odti,
            ols=ols,
            oltv=oltv,
            age=age,
            credit_score=credit_score,
        )

        pool_service_get_quartiles_response_200_quartiles_item.additional_properties = d
        return pool_service_get_quartiles_response_200_quartiles_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.186.0-py3-none-any.whl: infima_client/models/pool_service_get_quartiles_response_200_quartiles_item.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.pool_service_get_quartiles_response_200_quartiles_item_age import (
    PoolService_GetQuartilesResponse_200QuartilesItemAge,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_ocs import (
    PoolService_GetQuartilesResponse_200QuartilesItemOcs,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_odti import (
    PoolService_GetQuartilesResponse_200QuartilesItemOdti,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_ols import (
    PoolService_GetQuartilesResponse_200QuartilesItemOls,
)
from ..models.pool_service_get_quartiles_response_200_quartiles_item_oltv import (
    PoolService_GetQuartilesResponse_200QuartilesItemOltv,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolService_GetQuartilesResponse_200QuartilesItem")


@attr.s(auto_attribs=True)
class PoolService_GetQuartilesResponse_200QuartilesItem:
    """ Quartiles data on Loans characteristics: OCS, OLTV, OLS, Age, ODTI. """

    age: Union[PoolService_GetQuartilesResponse_200QuartilesItemAge, Unset] = UNSET
    cusip: Union[Unset, str] = UNSET
    ocs: Union[PoolService_GetQuartilesResponse_200QuartilesItemOcs, Unset] = UNSET
    odti: Union[PoolService_GetQuartilesResponse_200QuartilesItemOdti, Unset] = UNSET
    ols: Union[PoolService_GetQuartilesResponse_200QuartilesItemOls, Unset] = UNSET
    oltv: Union[PoolService_GetQuartilesResponse_200QuartilesItemOltv, Unset] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        age: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.age, Unset):
            age = self.age.to_dict()

        cusip = self.cusip
        ocs: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ocs, Unset):
            ocs = self.ocs.to_dict()

        odti: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.odti, Unset):
            odti = self.odti.to_dict()

        ols: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.ols, Unset):
            ols = self.ols.to_dict()

        oltv: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.oltv, Unset):
            oltv = self.oltv.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if age is not UNSET:
            field_dict["age"] = age
        if cusip is not UNSET:
            field_dict["cusip"] = cusip
        if ocs is not UNSET:
            field_dict["ocs"] = ocs
        if odti is not UNSET:
            field_dict["odti"] = odti
        if ols is not UNSET:
            field_dict["ols"] = ols
        if oltv is not UNSET:
            field_dict["oltv"] = oltv

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        age: Union[PoolService_GetQuartilesResponse_200QuartilesItemAge, Unset] = UNSET
        _age = d.pop("age", UNSET)
        if not isinstance(_age, Unset):
            age = PoolService_GetQuartilesResponse_200QuartilesItemAge.from_dict(
                cast(Dict[str, Any], _age)
            )

        cusip = d.pop("cusip", UNSET)

        ocs: Union[PoolService_GetQuartilesResponse_200QuartilesItemOcs, Unset] = UNSET
        _ocs = d.pop("ocs", UNSET)
        if not isinstance(_ocs, Unset):
            ocs = PoolService_GetQuartilesResponse_200QuartilesItemOcs.from_dict(
                cast(Dict[str, Any], _ocs)
            )

        odti: Union[
            PoolService_GetQuartilesResponse_200QuartilesItemOdti, Unset
        ] = UNSET
        _odti = d.pop("odti", UNSET)
        if not isinstance(_odti, Unset):
            odti = PoolService_GetQuartilesResponse_200QuartilesItemOdti.from_dict(
                cast(Dict[str, Any], _odti)
            )

        ols: Union[PoolService_GetQuartilesResponse_200QuartilesItemOls, Unset] = UNSET
        _ols = d.pop("ols", UNSET)
        if not isinstance(_ols, Unset):
            ols = PoolService_GetQuartilesResponse_200QuartilesItemOls.from_dict(
                cast(Dict[str, Any], _ols)
            )

        oltv: Union[
            PoolService_GetQuartilesResponse_200QuartilesItemOltv, Unset
        ] = UNSET
        _oltv = d.pop("oltv", UNSET)
        if not isinstance(_oltv, Unset):
            oltv = PoolService_GetQuartilesResponse_200QuartilesItemOltv.from_dict(
                cast(Dict[str, Any], _oltv)
            )

        pool_service_get_quartiles_response_200_quartiles_item = cls(
            age=age,
            cusip=cusip,
            ocs=ocs,
            odti=odti,
            ols=ols,
            oltv=oltv,
        )

        pool_service_get_quartiles_response_200_quartiles_item.additional_properties = d
        return pool_service_get_quartiles_response_200_quartiles_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
